@@ -6,13 +6,13 @@
 #include <net-snmp/net-snmp-config.h>
 #include "mibII_common.h"
 
-#if HAVE_SYS_HASHING_H
+#ifdef HAVE_SYS_HASHING_H
 #include <sys/hashing.h>
 #endif
-#if HAVE_NETINET_IN_VAR_H
+#ifdef HAVE_NETINET_IN_VAR_H
 #include <netinet/in_var.h>
 #endif
-#if HAVE_SYSLOG_H
+#ifdef HAVE_SYSLOG_H
 #include <syslog.h>
 #endif
 
@@ -59,9 +59,6 @@ perfstat_id_t ps_name;
 	 *
 	 *********************/
 
-extern void     init_routes(void);
-
-
 /*
  * define the structure we're going to ask the agent to register our
  * information at 
@@ -238,15 +235,11 @@ init_ip(void)
 #endif
 
 #ifdef HAVE_IPHLPAPI_H
-#define VACMVIEWSTATUS VIEWSTATUS
-#undef VIEWSTATUS
 #include <iphlpapi.h>
 #define IP_STAT_STRUCTURE MIB_IPSTATS
 long            ipForwarding;
 long            oldipForwarding;
 long            ipTTL, oldipTTL;
-#define VIEWSTATUS VACMVIEWSTATUS
-#undef VACMVIEWSTATUS
 #endif                          /* WIN32 cygwin */
 
 #ifdef HAVE_SYS_TCPIPSTATS_H
@@ -890,7 +883,7 @@ ip_load(netsnmp_cache *cache, void *vmagic)
     int             i;
     static int      sname[4] = { CTL_NET, PF_INET, IPPROTO_IP, 0 };
     size_t          len;
-    int             magic = (int) vmagic;
+    int             magic = (uintptr_t) vmagic;
 
     switch (magic) {
     case IPFORWARDING:
